document.addEventListener('DOMContentLoaded', () => {
    const analyzeBtn = document.getElementById('analyze-btn');
    const workoutInput = document.getElementById('workout-input');
    const exerciseList = document.getElementById('exercise-list');
    const videoContainer = document.getElementById('video-container');

    // Sample exercise database
    const exerciseDatabase = {
        'burpee': {
            description: 'A full-body exercise combining a squat, push-up, and jump',
            videoId: 'TU8QYVW0gDU'
        },
        'pull-up': {
            description: 'Upper body exercise lifting body weight using overhead grip',
            videoId: 'eGo4IYlbE5g'
        },
        'deadlift': {
            description: 'A weight training exercise lifting a loaded barbell off the ground',
            videoId: 'op9kVnSso6Q'
        }
    };

    analyzeBtn.addEventListener('click', () => {
        const workout = workoutInput.value.toLowerCase();
        const foundExercises = [];

        // Simple parsing logic (can be expanded)
        Object.keys(exerciseDatabase).forEach(exercise => {
            if (workout.includes(exercise)) {
                foundExercises.push(exercise);
            }
        });

        displayExercises(foundExercises);
    });

    function displayExercises(exercises) {
        exerciseList.innerHTML = '';
        exercises.forEach(exercise => {
            const exerciseDiv = document.createElement('div');
            exerciseDiv.className = 'exercise-item';
            exerciseDiv.innerHTML = `
                <h3>${exercise.charAt(0).toUpperCase() + exercise.slice(1)}</h3>
                <p>${exerciseDatabase[exercise].description}</p>
            `;
            
            exerciseDiv.addEventListener('click', () => {
                document.querySelectorAll('.exercise-item').forEach(item => {
                    item.classList.remove('active');
                });
                exerciseDiv.classList.add('active');
                showVideo(exercise);
            });

            exerciseList.appendChild(exerciseDiv);
        });
    }

    function showVideo(exercise) {
        const videoId = exerciseDatabase[exercise].videoId;
        videoContainer.innerHTML = `
            <iframe 
                width="100%" 
                height="100%" 
                src="https://www.youtube.com/embed/${videoId}"
                frameborder="0" 
                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" 
                allowfullscreen>
            </iframe>
        `;
    }
});
